@@ -62,8 +62,7 @@ class UpFirDnUpsample(nn.Module):
         self.pad = ((pad + 1) // 2 + factor - 1, pad // 2)
 
     def forward(self, x):
-        out = upfirdn2d(
-            x, self.kernel.type_as(x), up=self.factor, down=1, pad=self.pad)
+        out = upfirdn2d(x, self.kernel.type_as(x), up=self.factor, down=1, pad=self.pad)
         return out
 
     def __repr__(self):
@@ -88,8 +87,7 @@ class UpFirDnDownsample(nn.Module):
         self.pad = ((pad + 1) // 2, pad // 2)
 
     def forward(self, x):
-        out = upfirdn2d(
-            x, self.kernel.type_as(x), up=1, down=self.factor, pad=self.pad)
+        out = upfirdn2d(x, self.kernel.type_as(x), up=1, down=self.factor, pad=self.pad)
         return out
 
     def __repr__(self):
@@ -107,11 +105,7 @@ class UpFirDnSmooth(nn.Module):
         kernel_size (int): Kernel size: Deafult: 1.
     """
 
-    def __init__(self,
-                 resample_kernel,
-                 upsample_factor=1,
-                 downsample_factor=1,
-                 kernel_size=1):
+    def __init__(self, resample_kernel, upsample_factor=1, downsample_factor=1, kernel_size=1):
         super(UpFirDnSmooth, self).__init__()
         self.upsample_factor = upsample_factor
         self.downsample_factor = downsample_factor
@@ -123,8 +117,7 @@ class UpFirDnSmooth(nn.Module):
             pad = (self.kernel.shape[0] - upsample_factor) - (kernel_size - 1)
             self.pad = ((pad + 1) // 2 + upsample_factor - 1, pad // 2 + 1)
         elif downsample_factor > 1:
-            pad = (self.kernel.shape[0] - downsample_factor) + (
-                kernel_size - 1)
+            pad = (self.kernel.shape[0] - downsample_factor) + (kernel_size - 1)
             self.pad = ((pad + 1) // 2, pad // 2)
         else:
             raise NotImplementedError
@@ -134,9 +127,8 @@ class UpFirDnSmooth(nn.Module):
         return out
 
     def __repr__(self):
-        return (
-            f'{self.__class__.__name__}(upsample_factor={self.upsample_factor}'
-            f', downsample_factor={self.downsample_factor})')
+        return (f'{self.__class__.__name__}(upsample_factor={self.upsample_factor}'
+                f', downsample_factor={self.downsample_factor})')
 
 
 class EqualLinear(nn.Module):
@@ -153,29 +145,20 @@ class EqualLinear(nn.Module):
             Supported: 'fused_lrelu', None. Default: None.
     """
 
-    def __init__(self,
-                 in_channels,
-                 out_channels,
-                 bias=True,
-                 bias_init_val=0,
-                 lr_mul=1,
-                 activation=None):
+    def __init__(self, in_channels, out_channels, bias=True, bias_init_val=0, lr_mul=1, activation=None):
         super(EqualLinear, self).__init__()
         self.in_channels = in_channels
         self.out_channels = out_channels
         self.lr_mul = lr_mul
         self.activation = activation
         if self.activation not in ['fused_lrelu', None]:
-            raise ValueError(
-                f'Wrong activation value in EqualLinear: {activation}'
-                "Supported ones are: ['fused_lrelu', None].")
+            raise ValueError(f'Wrong activation value in EqualLinear: {activation}'
+                             "Supported ones are: ['fused_lrelu', None].")
         self.scale = (1 / math.sqrt(in_channels)) * lr_mul
 
-        self.weight = nn.Parameter(
-            torch.randn(out_channels, in_channels).div_(lr_mul))
+        self.weight = nn.Parameter(torch.randn(out_channels, in_channels).div_(lr_mul))
         if bias:
-            self.bias = nn.Parameter(
-                torch.zeros(out_channels).fill_(bias_init_val))
+            self.bias = nn.Parameter(torch.zeros(out_channels).fill_(bias_init_val))
         else:
             self.register_parameter('bias', None)
 
@@ -192,9 +175,8 @@ class EqualLinear(nn.Module):
         return out
 
     def __repr__(self):
-        return (
-            f'{self.__class__.__name__}(in_channels={self.in_channels}, '
-            f'out_channels={self.out_channels}, bias={self.bias is not None})')
+        return (f'{self.__class__.__name__}(in_channels={self.in_channels}, '
+                f'out_channels={self.out_channels}, bias={self.bias is not None})')
 
 
 class ModulatedConv2d(nn.Module):
@@ -236,36 +218,22 @@ class ModulatedConv2d(nn.Module):
 
         if self.sample_mode == 'upsample':
             self.smooth = UpFirDnSmooth(
-                resample_kernel,
-                upsample_factor=2,
-                downsample_factor=1,
-                kernel_size=kernel_size)
+                resample_kernel, upsample_factor=2, downsample_factor=1, kernel_size=kernel_size)
         elif self.sample_mode == 'downsample':
             self.smooth = UpFirDnSmooth(
-                resample_kernel,
-                upsample_factor=1,
-                downsample_factor=2,
-                kernel_size=kernel_size)
+                resample_kernel, upsample_factor=1, downsample_factor=2, kernel_size=kernel_size)
         elif self.sample_mode is None:
             pass
         else:
-            raise ValueError(
-                f'Wrong sample mode {self.sample_mode}, '
-                "supported ones are ['upsample', 'downsample', None].")
+            raise ValueError(f'Wrong sample mode {self.sample_mode}, '
+                             "supported ones are ['upsample', 'downsample', None].")
 
         self.scale = 1 / math.sqrt(in_channels * kernel_size**2)
         # modulation inside each modulated conv
         self.modulation = EqualLinear(
-            num_style_feat,
-            in_channels,
-            bias=True,
-            bias_init_val=1,
-            lr_mul=1,
-            activation=None)
+            num_style_feat, in_channels, bias=True, bias_init_val=1, lr_mul=1, activation=None)
 
-        self.weight = nn.Parameter(
-            torch.randn(1, out_channels, in_channels, kernel_size,
-                        kernel_size))
+        self.weight = nn.Parameter(torch.randn(1, out_channels, in_channels, kernel_size, kernel_size))
         self.padding = kernel_size // 2
 
     def forward(self, x, style):
@@ -288,16 +256,12 @@ class ModulatedConv2d(nn.Module):
             demod = torch.rsqrt(weight.pow(2).sum([2, 3, 4]) + self.eps)
             weight = weight * demod.view(b, self.out_channels, 1, 1, 1)
 
-        weight = weight.view(b * self.out_channels, c, self.kernel_size,
-                             self.kernel_size)
+        weight = weight.view(b * self.out_channels, c, self.kernel_size, self.kernel_size)
 
         if self.sample_mode == 'upsample':
             x = x.view(1, b * c, h, w)
-            weight = weight.view(b, self.out_channels, c, self.kernel_size,
-                                 self.kernel_size)
-            weight = weight.transpose(1, 2).reshape(b * c, self.out_channels,
-                                                    self.kernel_size,
-                                                    self.kernel_size)
+            weight = weight.view(b, self.out_channels, c, self.kernel_size, self.kernel_size)
+            weight = weight.transpose(1, 2).reshape(b * c, self.out_channels, self.kernel_size, self.kernel_size)
             out = F.conv_transpose2d(x, weight, padding=0, stride=2, groups=b)
             out = out.view(b, self.out_channels, *out.shape[2:4])
             out = self.smooth(out)
@@ -315,11 +279,10 @@ class ModulatedConv2d(nn.Module):
         return out
 
     def __repr__(self):
-        return (
-            f'{self.__class__.__name__}(in_channels={self.in_channels}, '
-            f'out_channels={self.out_channels}, '
-            f'kernel_size={self.kernel_size}, '
-            f'demodulate={self.demodulate}, sample_mode={self.sample_mode})')
+        return (f'{self.__class__.__name__}(in_channels={self.in_channels}, '
+                f'out_channels={self.out_channels}, '
+                f'kernel_size={self.kernel_size}, '
+                f'demodulate={self.demodulate}, sample_mode={self.sample_mode})')
 
 
 class StyleConv(nn.Module):
@@ -381,23 +344,14 @@ class ToRGB(nn.Module):
             magnitude. Default: (1, 3, 3, 1).
     """
 
-    def __init__(self,
-                 in_channels,
-                 num_style_feat,
-                 upsample=True,
-                 resample_kernel=(1, 3, 3, 1)):
+    def __init__(self, in_channels, num_style_feat, upsample=True, resample_kernel=(1, 3, 3, 1)):
         super(ToRGB, self).__init__()
         if upsample:
             self.upsample = UpFirDnUpsample(resample_kernel, factor=2)
         else:
             self.upsample = None
         self.modulated_conv = ModulatedConv2d(
-            in_channels,
-            3,
-            kernel_size=1,
-            num_style_feat=num_style_feat,
-            demodulate=False,
-            sample_mode=None)
+            in_channels, 3, kernel_size=1, num_style_feat=num_style_feat, demodulate=False, sample_mode=None)
         self.bias = nn.Parameter(torch.zeros(1, 3, 1, 1))
 
     def forward(self, x, style, skip=None):
@@ -469,11 +423,7 @@ class StyleGAN2Generator(nn.Module):
         for i in range(num_mlp):
             style_mlp_layers.append(
                 EqualLinear(
-                    num_style_feat,
-                    num_style_feat,
-                    bias=True,
-                    bias_init_val=0,
-                    lr_mul=lr_mlp,
+                    num_style_feat, num_style_feat, bias=True, bias_init_val=0, lr_mul=lr_mlp,
                     activation='fused_lrelu'))
         self.style_mlp = nn.Sequential(*style_mlp_layers)
 
@@ -499,11 +449,7 @@ class StyleGAN2Generator(nn.Module):
             demodulate=True,
             sample_mode=None,
             resample_kernel=resample_kernel)
-        self.to_rgb1 = ToRGB(
-            channels['4'],
-            num_style_feat,
-            upsample=False,
-            resample_kernel=resample_kernel)
+        self.to_rgb1 = ToRGB(channels['4'], num_style_feat, upsample=False, resample_kernel=resample_kernel)
 
         self.log_size = int(math.log(out_size, 2))
         self.num_layers = (self.log_size - 2) * 2 + 1
@@ -518,8 +464,7 @@ class StyleGAN2Generator(nn.Module):
         for layer_idx in range(self.num_layers):
             resolution = 2**((layer_idx + 5) // 2)
             shape = [1, 1, resolution, resolution]
-            self.noises.register_buffer(f'noise{layer_idx}',
-                                        torch.randn(*shape))
+            self.noises.register_buffer(f'noise{layer_idx}', torch.randn(*shape))
         # style convs and to_rgbs
         for i in range(3, self.log_size + 1):
             out_channels = channels[f'{2**i}']
@@ -542,12 +487,7 @@ class StyleGAN2Generator(nn.Module):
                     demodulate=True,
                     sample_mode=None,
                     resample_kernel=resample_kernel))
-            self.to_rgbs.append(
-                ToRGB(
-                    out_channels,
-                    num_style_feat,
-                    upsample=True,
-                    resample_kernel=resample_kernel))
+            self.to_rgbs.append(ToRGB(out_channels, num_style_feat, upsample=True, resample_kernel=resample_kernel))
             in_channels = out_channels
 
     def make_noise(self):
@@ -565,10 +505,7 @@ class StyleGAN2Generator(nn.Module):
         return self.style_mlp(x)
 
     def mean_latent(self, num_latent):
-        latent_in = torch.randn(
-            num_latent,
-            self.num_style_feat,
-            device=self.constant_input.weight.device)
+        latent_in = torch.randn(num_latent, self.num_style_feat, device=self.constant_input.weight.device)
         latent = self.style_mlp(latent_in).mean(0, keepdim=True)
         return latent
 
@@ -605,16 +542,12 @@ class StyleGAN2Generator(nn.Module):
             if randomize_noise:
                 noise = [None] * self.num_layers  # for each style conv layer
             else:  # use the stored noise
-                noise = [
-                    getattr(self.noises, f'noise{i}')
-                    for i in range(self.num_layers)
-                ]
+                noise = [getattr(self.noises, f'noise{i}') for i in range(self.num_layers)]
         # style truncation
         if truncation < 1:
             style_truncation = []
             for style in styles:
-                style_truncation.append(truncation_latent + truncation *
-                                        (style - truncation_latent))
+                style_truncation.append(truncation_latent + truncation * (style - truncation_latent))
             styles = style_truncation
         # get style latent with injection
         if len(styles) == 1:
@@ -629,8 +562,7 @@ class StyleGAN2Generator(nn.Module):
             if inject_index is None:
                 inject_index = random.randint(1, self.num_latent - 1)
             latent1 = styles[0].unsqueeze(1).repeat(1, inject_index, 1)
-            latent2 = styles[1].unsqueeze(1).repeat(
-                1, self.num_latent - inject_index, 1)
+            latent2 = styles[1].unsqueeze(1).repeat(1, self.num_latent - inject_index, 1)
             latent = torch.cat([latent1, latent2], 1)
 
         # main generation
@@ -639,9 +571,8 @@ class StyleGAN2Generator(nn.Module):
         skip = self.to_rgb1(out, latent[:, 1])
 
         i = 1
-        for conv1, conv2, noise1, noise2, to_rgb in zip(
-                self.style_convs[::2], self.style_convs[1::2], noise[1::2],
-                noise[2::2], self.to_rgbs):
+        for conv1, conv2, noise1, noise2, to_rgb in zip(self.style_convs[::2], self.style_convs[1::2], noise[1::2],
+                                                        noise[2::2], self.to_rgbs):
             out = conv1(out, latent[:, i], noise=noise1)
             out = conv2(out, latent[:, i + 1], noise=noise2)
             skip = to_rgb(out, latent[:, i + 2], skip)
@@ -686,14 +617,7 @@ class EqualConv2d(nn.Module):
         bias_init_val (float): Bias initialized value. Default: 0.
     """
 
-    def __init__(self,
-                 in_channels,
-                 out_channels,
-                 kernel_size,
-                 stride=1,
-                 padding=0,
-                 bias=True,
-                 bias_init_val=0):
+    def __init__(self, in_channels, out_channels, kernel_size, stride=1, padding=0, bias=True, bias_init_val=0):
         super(EqualConv2d, self).__init__()
         self.in_channels = in_channels
         self.out_channels = out_channels
@@ -702,11 +626,9 @@ class EqualConv2d(nn.Module):
         self.padding = padding
         self.scale = 1 / math.sqrt(in_channels * kernel_size**2)
 
-        self.weight = nn.Parameter(
-            torch.randn(out_channels, in_channels, kernel_size, kernel_size))
+        self.weight = nn.Parameter(torch.randn(out_channels, in_channels, kernel_size, kernel_size))
         if bias:
-            self.bias = nn.Parameter(
-                torch.zeros(out_channels).fill_(bias_init_val))
+            self.bias = nn.Parameter(torch.zeros(out_channels).fill_(bias_init_val))
         else:
             self.register_parameter('bias', None)
 
@@ -758,11 +680,7 @@ class ConvLayer(nn.Sequential):
         # downsample
         if downsample:
             layers.append(
-                UpFirDnSmooth(
-                    resample_kernel,
-                    upsample_factor=1,
-                    downsample_factor=2,
-                    kernel_size=kernel_size))
+                UpFirDnSmooth(resample_kernel, upsample_factor=1, downsample_factor=2, kernel_size=kernel_size))
             stride = 2
             self.padding = 0
         else:
@@ -771,12 +689,8 @@ class ConvLayer(nn.Sequential):
         # conv
         layers.append(
             EqualConv2d(
-                in_channels,
-                out_channels,
-                kernel_size,
-                stride=stride,
-                padding=self.padding,
-                bias=bias and not activate))
+                in_channels, out_channels, kernel_size, stride=stride, padding=self.padding, bias=bias
+                and not activate))
         # activation
         if activate:
             if bias:
@@ -799,28 +713,14 @@ class ResBlock(nn.Module):
             Default: (1, 3, 3, 1).
     """
 
-    def __init__(self, in_channels, out_channels,
-                 resample_kernel=(1, 3, 3, 1)):
+    def __init__(self, in_channels, out_channels, resample_kernel=(1, 3, 3, 1)):
         super(ResBlock, self).__init__()
 
-        self.conv1 = ConvLayer(
-            in_channels, in_channels, 3, bias=True, activate=True)
+        self.conv1 = ConvLayer(in_channels, in_channels, 3, bias=True, activate=True)
         self.conv2 = ConvLayer(
-            in_channels,
-            out_channels,
-            3,
-            downsample=True,
-            resample_kernel=resample_kernel,
-            bias=True,
-            activate=True)
+            in_channels, out_channels, 3, downsample=True, resample_kernel=resample_kernel, bias=True, activate=True)
         self.skip = ConvLayer(
-            in_channels,
-            out_channels,
-            1,
-            downsample=True,
-            resample_kernel=resample_kernel,
-            bias=False,
-            activate=False)
+            in_channels, out_channels, 1, downsample=True, resample_kernel=resample_kernel, bias=False, activate=False)
 
     def forward(self, x):
         out = self.conv1(x)
@@ -845,12 +745,7 @@ class StyleGAN2Discriminator(nn.Module):
         narrow (float): Narrow ratio for channels. Default: 1.0.
     """
 
-    def __init__(self,
-                 out_size,
-                 channel_multiplier=2,
-                 resample_kernel=(1, 3, 3, 1),
-                 stddev_group=4,
-                 narrow=1):
+    def __init__(self, out_size, channel_multiplier=2, resample_kernel=(1, 3, 3, 1), stddev_group=4, narrow=1):
         super(StyleGAN2Discriminator, self).__init__()
 
         channels = {
@@ -867,35 +762,20 @@ class StyleGAN2Discriminator(nn.Module):
 
         log_size = int(math.log(out_size, 2))
 
-        conv_body = [
-            ConvLayer(3, channels[f'{out_size}'], 1, bias=True, activate=True)
-        ]
+        conv_body = [ConvLayer(3, channels[f'{out_size}'], 1, bias=True, activate=True)]
 
         in_channels = channels[f'{out_size}']
         for i in range(log_size, 2, -1):
             out_channels = channels[f'{2**(i - 1)}']
-            conv_body.append(
-                ResBlock(in_channels, out_channels, resample_kernel))
+            conv_body.append(ResBlock(in_channels, out_channels, resample_kernel))
             in_channels = out_channels
         self.conv_body = nn.Sequential(*conv_body)
 
-        self.final_conv = ConvLayer(
-            in_channels + 1, channels['4'], 3, bias=True, activate=True)
+        self.final_conv = ConvLayer(in_channels + 1, channels['4'], 3, bias=True, activate=True)
         self.final_linear = nn.Sequential(
             EqualLinear(
-                channels['4'] * 4 * 4,
-                channels['4'],
-                bias=True,
-                bias_init_val=0,
-                lr_mul=1,
-                activation='fused_lrelu'),
-            EqualLinear(
-                channels['4'],
-                1,
-                bias=True,
-                bias_init_val=0,
-                lr_mul=1,
-                activation=None),
+                channels['4'] * 4 * 4, channels['4'], bias=True, bias_init_val=0, lr_mul=1, activation='fused_lrelu'),
+            EqualLinear(channels['4'], 1, bias=True, bias_init_val=0, lr_mul=1, activation=None),
         )
         self.stddev_group = stddev_group
         self.stddev_feat = 1
@@ -905,11 +785,8 @@ class StyleGAN2Discriminator(nn.Module):
 
         b, c, h, w = out.shape
         # concatenate a group stddev statistics to out
-        group = min(
-            b, self.stddev_group
-        )  # Minibatch must be divisible by (or smaller than) group_size
-        stddev = out.view(group, -1, self.stddev_feat, c // self.stddev_feat,
-                          h, w)
+        group = min(b, self.stddev_group)  # Minibatch must be divisible by (or smaller than) group_size
+        stddev = out.view(group, -1, self.stddev_feat, c // self.stddev_feat, h, w)
         stddev = torch.sqrt(stddev.var(0, unbiased=False) + 1e-8)
         stddev = stddev.mean([2, 3, 4], keepdims=True).squeeze(2)
         stddev = stddev.repeat(group, 1, h, w)
